==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/ALERTGRIDPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ALERTGRIDPARAMETERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ALERTGRIDPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALERTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDPARAMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTGRIDPARAMETERID_Type", propOrder = {
    "alertid",
    "gridparamid"
})
public class ALERTGRIDPARAMETERID_Type {

    @XmlElement(name = "ALERTID", required = true)
    protected ALERTID_Type alertid;
    @XmlElement(name = "GRIDPARAMID", required = true)
    protected String gridparamid;

    /**
     * Obtient la valeur de la propriété alertid.
     * 
     * @return
     *     possible object is
     *     {@link ALERTID_Type }
     *     
     */
    public ALERTID_Type getALERTID() {
        return alertid;
    }

    /**
     * Définit la valeur de la propriété alertid.
     * 
     * @param value
     *     allowed object is
     *     {@link ALERTID_Type }
     *     
     */
    public void setALERTID(ALERTID_Type value) {
        this.alertid = value;
    }

    /**
     * Obtient la valeur de la propriété gridparamid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDPARAMID() {
        return gridparamid;
    }

    /**
     * Définit la valeur de la propriété gridparamid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDPARAMID(String value) {
        this.gridparamid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/ALERTGRIDPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ALERTGRIDPARAMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ALERTGRIDPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALERTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDPARAMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTGRIDPARAMETERID_Type", propOrder = {
    "alertid",
    "gridparamid"
})
public class ALERTGRIDPARAMETERID_Type {

    @XmlElement(name = "ALERTID", required = true)
    protected ALERTID_Type alertid;
    @XmlElement(name = "GRIDPARAMID", required = true)
    protected String gridparamid;

    /**
     * Gets the value of the alertid property.
     * 
     * @return
     *     possible object is
     *     {@link ALERTID_Type }
     *     
     */
    public ALERTID_Type getALERTID() {
        return alertid;
    }

    /**
     * Sets the value of the alertid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ALERTID_Type }
     *     
     */
    public void setALERTID(ALERTID_Type value) {
        this.alertid = value;
    }

    /**
     * Gets the value of the gridparamid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDPARAMID() {
        return gridparamid;
    }

    /**
     * Sets the value of the gridparamid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDPARAMID(String value) {
        this.gridparamid = value;
    }

}
